==> sca-patterns-sle12-1.5.5.tar.gz: sca-patterns-sle12-1.5.5/patterns/SLE/sle12sp5/imagemagick_SUSE-SU-2020_3163-1_12.5.py <==
#!/usr/bin/python3
#
# Title:       Moderate Security Announcement for ImageMagick SUSE-SU-2020:3163-1
# Description: Security fixes for SUSE Linux Enterprise 12 SP5
# Source:      Security Announcement Parser v1.5.2
# Modified:    2020 Nov 16
#
##############################################################################
# Copyright (C) 2020 SUSE LLC
##############################################################################
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 of the License.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, see <http://www.gnu.org/licenses/>.
#
#  Authors/Contributors:
#   Jason Record (jason.record@suse.com)
#
##############################################################################

import os
import Core
import SUSE

META_CLASS = "Security"
META_CATEGORY = "SLE"
META_COMPONENT = "ImageMagick"
PATTERN_ID = os.path.basename(__file__)
PRIMARY_LINK = "META_LINK_Security"
OVERALL = Core.TEMP
OVERALL_INFO = "NOT SET"
OTHER_LINKS = "META_LINK_Security=https://lists.suse.com/pipermail/sle-security-updates/2020-November/007703.html"
Core.init(META_CLASS, META_CATEGORY, META_COMPONENT, PATTERN_ID, PRIMARY_LINK, OVERALL, OVERALL_INFO, OTHER_LINKS)

LTSS = False
NAME = 'ImageMagick'
MAIN = ''
SEVERITY = 'Moderate'
TAG = 'SUSE-SU-2020:3163-1'
PACKAGES = {}
SERVER = SUSE.getHostInfo()

if ( SERVER['DistroVersion'] == 12):
	if ( SERVER['DistroPatchLevel'] == 5 ):
		PACKAGES = {
			'ImageMagick': '6.8.8.1-71.147.1',
			'ImageMagick-config-6-SUSE': '6.8.8.1-71.147.1',
			'ImageMagick-config-6-upstream': '6.8.8.1-71.147.1',
			'ImageMagick-debuginfo': '6.8.8.1-71.147.1',
			'ImageMagick-debugsource': '6.8.8.1-71.147.1',
			'ImageMagick-devel': '6.8.8.1-71.147.1',
			'libMagick++-6_Q16-3': '6.8.8.1-71.147.1',
			'libMagick++-6_Q16-3-debuginfo': '6.8.8.1-71.147.1',
			'libMagick++-devel': '6.8.8.1-71.147.1',
			'libMagickCore-6_Q16-1': '6.8.8.1-71.147.1',
			'libMagickCore-6_Q16-1-32bit': '6.8.8.1-71.147.1',
			'libMagickCore-6_Q16-1-debuginfo': '6.8.8.1-71.147.1',
			'libMagickCore-6_Q16-1-debuginfo-32bit': '6.8.8.1-71.147.1',
			'libMagickWand-6_Q16-1': '6.8.8.1-71.147.1',
			'libMagickWand-6_Q16-1-debuginfo': '6.8.8.1-71.147.1',
			'perl-PerlMagick': '6.8.8.1-71.147.1',
			'perl-PerlMagick-debuginfo': '6.8.8.1-71.147.1',
		}
		SUSE.securityAnnouncementPackageCheck(NAME, MAIN, LTSS, SEVERITY, TAG, PACKAGES)
	else:
		Core.updateStatus(Core.ERROR, "ERROR: " + NAME + " Security Announcement: Outside the service pack scope")
else:
	Core.updateStatus(Core.ERROR, "ERROR: " + NAME + " Security Announcement: Outside the distribution scope")
Core.printPatternResults()

==> sca-patterns-sle12-1.5.7.tar.gz: sca-patterns-sle12-1.5.7/patterns/SLE/sle12sp5/imagemagick_SUSE-SU-2020_2750-1_12.5.py <==
#!/usr/bin/python3
#
# Title:       Moderate Security Announcement for ImageMagick SUSE-SU-2020:2750-1
# Description: Security fixes for SUSE Linux Enterprise 12 SP5
# Source:      Security Announcement Parser v1.5.2
# Modified:    2020 Nov 16
#
##############################################################################
# Copyright (C) 2020 SUSE LLC
##############################################################################
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 of the License.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, see <http://www.gnu.org/licenses/>.
#
#  Authors/Contributors:
#   Jason Record (jason.record@suse.com)
#
##############################################################################

import os
import Core
import SUSE

META_CLASS = "Security"
META_CATEGORY = "SLE"
META_COMPONENT = "ImageMagick"
PATTERN_ID = os.path.basename(__file__)
PRIMARY_LINK = "META_LINK_Security"
OVERALL = Core.TEMP
OVERALL_INFO = "NOT SET"
OTHER_LINKS = "META_LINK_Security=https://lists.suse.com/pipermail/sle-security-updates/2020-September/007482.html"
Core.init(META_CLASS, META_CATEGORY, META_COMPONENT, PATTERN_ID, PRIMARY_LINK, OVERALL, OVERALL_INFO, OTHER_LINKS)

LTSS = False
NAME = 'ImageMagick'
MAIN = ''
SEVERITY = 'Moderate'
TAG = 'SUSE-SU-2020:2750-1'
PACKAGES = {}
SERVER = SUSE.getHostInfo()

if ( SERVER['DistroVersion'] == 12):
	if ( SERVER['DistroPatchLevel'] == 5 ):
		PACKAGES = {
			'ImageMagick': '6.8.8.1-71.144.8',
			'ImageMagick-config-6-SUSE': '6.8.8.1-71.144.8',
			'ImageMagick-config-6-upstream': '6.8.8.1-71.144.8',
			'ImageMagick-debuginfo': '6.8.8.1-71.144.8',
			'ImageMagick-debugsource': '6.8.8.1-71.144.8',
			'ImageMagick-devel': '6.8.8.1-71.144.8',
			'libMagick++-6_Q16-3': '6.8.8.1-71.144.8',
			'libMagick++-6_Q16-3-debuginfo': '6.8.8.1-71.144.8',
			'libMagick++-devel': '6.8.8.1-71.144.8',
			'libMagickCore-6_Q16-1': '6.8.8.1-71.144.8',
			'libMagickCore-6_Q16-1-32bit': '6.8.8.1-71.144.8',
			'libMagickCore-6_Q16-1-debuginfo': '6.8.8.1-71.144.8',
			'libMagickCore-6_Q16-1-debuginfo-32bit': '6.8.8.1-71.144.8',
			'libMagickWand-6_Q16-1': '6.8.8.1-71.144.8',
			'libMagickWand-6_Q16-1-debuginfo': '6.8.8.1-71.144.8',
			'perl-PerlMagick': '6.8.8.1-71.144.8',
			'perl-PerlMagick-debuginfo': '6.8.8.1-71.144.8',
		}
		SUSE.securityAnnouncementPackageCheck(NAME, MAIN, LTSS, SEVERITY, TAG, PACKAGES)
	else:
		Core.updateStatus(Core.ERROR, "ERROR: " + NAME + " Security Announcement: Outside the service pack scope")
else:
	Core.updateStatus(Core.ERROR, "ERROR: " + NAME + " Security Announcement: Outside the distribution scope")
Core.printPatternResults()
